import React, { PropTypes, Component } from 'react';
import { Entity } from 'draft-js';
import styles from './styles.css';
import Option from '../../components/Option';
import link from '../../../../images/link.svg';
import linkifyIt from 'linkify-it';

function findLinkEntities(contentBlock, callback) {
  contentBlock.findEntityRanges(
    (character) => {
      const entityKey = character.getEntity();
      return (
        entityKey !== null &&
        Entity.get(entityKey).getType() === 'LINK'
      );
    },
    callback
  );
  const text = contentBlock.getText();
  const linkify = linkifyIt();
  const matchArr = linkify.match(text);
  if (matchArr && matchArr.length > 0) {
    matchArr.forEach((arr) => {
      callback(arr.index, arr.index + arr.text.length);
    });
  }
}

class Link extends Component {

  static propTypes = {
    entityKey: PropTypes.string.isRequired,
    children: PropTypes.any,
  };

  state: Object = {
    showPopOver: false,
  };

  _onLinkOptionClick: Function = () => {
    const { entityKey } = this.props;
    const { url } = Entity.get(entityKey).getData();
    const linkTab = window.open(url, '_blank');
    linkTab.focus();
  };

  _toggleShowPopOver: Function = () => {
    const showPopOver = !this.state.showPopOver;
    this.setState({
      showPopOver,
    });
  };

  render() {
    const { children } = this.props;
    const { showPopOver } = this.state;
    return (
      <span
        className={styles.linkoption_wrapper}
        onMouseEnter={this._toggleShowPopOver}
        onMouseLeave={this._toggleShowPopOver}
      >
        <span className={styles.linkoption_link}>{children}</span>
        {showPopOver ?
          <span className={styles.linkoption_container}>
            <span className={styles.linkoption_options}>
              <span className={styles.arrow_up} />
              <Option
                className={styles.linkoption_option}
                onClick={this._onLinkOptionClick}
              >
                <img
                  src={link}
                  role="presentation"
                  className={styles.linkoption_icon}
                />
              </Option>
            </span>
          </span>
          : undefined
        }
      </span>
    );
  }
}

export default {
  strategy: findLinkEntities,
  component: Link,
};
