import React, { PropTypes, Component } from 'react';
import { Entity } from 'draft-js';
import styles from './styles.css';
import Option from '../../components/Option';
import classNames from 'classnames';

export default class Image extends Component {

  static propTypes = {
    block: PropTypes.object.isRequired,
  };

  state: Object = {
    hovered: false,
    focused: false,
    mouseDown: false,
    imageWidth: 300,
    imageResizing: false,
  };

  componentWillMount() {
    document.addEventListener('mousedown', this._onDocumentMoueDown);
    document.addEventListener('mouseup', this._onDocumentMoueUp);
  }

  _setHovered = () => {
    this.setState({
      hovered: true,
    });
  };

  _resetHovered = () => {
    this.setState({
      hovered: false,
    });
  };

  _onMouseDown = () => {
    this.setState({
      focused: true,
      mouseDown: true,
    });
  };

  _onMouseUp = () => {
    this.setState({
      focused: true,
      mouseDown: false,
    });
  };

  _onDocumentMoueDown = () => {
    const { hovered } = this.state;
    if (!hovered) {
      this.setState({
        focused: false,
      });
    }
  };

  _onDocumentMoueUp = () => {
    this.setState({
      imageResizing: false,
    });
  };

  _setEntityAlignmentLeft = () => {
    this._setEntityData({ alignment: 'left' });
  };

  _setEntityAlignmentRight = () => {
    this._setEntityData({ alignment: 'right' });
  };

  _setEntityAlignmentNone = () => {
    this._setEntityData({ alignment: 'none' });
  };

  _setEntityData = (data) => {
    const { block } = this.props;
    const entityKey = block.getEntityAt(0);
    Entity.mergeData(
      entityKey,
      data
    );
    this.setState({
      dummy: true,
    });
  };

  _onMouseDownAtHandle = (event) => {
    this.mouseMoveOrigin = event.pageX;
    this.setState({
      imageResizing: true,
    });
  };

  _resizeImage = (event) => {
    const { imageResizing } = this.state;
    if (imageResizing) {
      const { block } = this.props;
      const entityKey = block.getEntityAt(0);
      const entity = Entity.get(entityKey);
      const width = entity.getData().width + (event.pageX - this.mouseMoveOrigin);
      if (width > 50 && width < 500) {
        Entity.mergeData(
          entityKey,
          { width }
        );
        this.setState({
          dummy: true,
        });
      }
    }
  }

  _renderAlignmentOptions(): Object {
    return (
      <div
        className={styles.image_alignmentOptionsPopup}
      >
        <Option
          onClick={this._setEntityAlignmentLeft}
          className={styles.image_alignmentOption}
        >
          L
        </Option>
        <Option
          onClick={this._setEntityAlignmentNone}
          className={styles.image_alignmentOption}
        >
          C
        </Option>
        <Option
          onClick={this._setEntityAlignmentRight}
          className={styles.image_alignmentOption}
        >
          R
        </Option>
      </div>
    );
  }

  _renderResizeOptions() {
    return (
      <div
        onMouseMove={this._resizeImage}
        onMouseDown={this._onMouseDownAtHandle}
        className={styles.image_resize_handle_wrapper}
      >
        <div className={styles.image_resize_handle}></div>
      </div>
    );
  }

  render() {
    const { block } = this.props;
    const { hovered, focused } = this.state;
    const entity = Entity.get(block.getEntityAt(0));
    const { src, alignment, width } = entity.getData();
    return (
      <span
        style={{ float: alignment }}
        onMouseEnter={this._setHovered}
        onMouseLeave={this._resetHovered}
        onMouseDown={this._onMouseDown}
        onMouseUp={this._onMouseUp}
        className={classNames(
          styles.image_imageWrapper,
          {
            [`${styles.image_left}`]: alignment === 'left',
            [`${styles.image_right}`]: alignment === 'right',
            [`${styles.image_none}`]: !alignment || alignment === 'none',
          }
        )}
      >
        <span className={styles.image_imagewrapper}>
          <img
            src={src}
            role="presentation"
            ref={this.imageDetails}
            style={{ width: width, height: 'auto' }}
            className={classNames(
              {
                [`${styles.resizingWrapper_focus}`]: focused,
              }
            )}
          />
          {
            hovered ?
              this._renderAlignmentOptions()
              :
              undefined
          }
          {
            focused ?
            this._renderResizeOptions()
            :
            undefined
          }
        </span>
      </span>
    );
  }
}
