/* @flow */

import React, { Component, PropTypes } from 'react';
import styles from './styles.css';
import { Dropdown, DropdownOption } from '../Dropdown';

export default class BlockControl extends Component {

  static propTypes = {
    onToggle: PropTypes.func.isRequired,
    currentBlockType: PropTypes.string,
  };

  blocksTypes: Array<Object> = [
    { label: 'Normal', style: 'unstyled' },
    { label: 'H1', style: 'header-one' },
    { label: 'H2', style: 'header-two' },
    { label: 'H3', style: 'header-three' },
    { label: 'H4', style: 'header-four' },
    { label: 'H5', style: 'header-five' },
    { label: 'H6', style: 'header-six' },
    { label: 'Blockquote', style: 'blockquote' },
  ];

  _onChange: Function = (value) => {
    if (value) {
      this.props.onToggle(value);
    }
  };

  render() {
    let { currentBlockType } = this.props;
    // As per reqirement show block type as normal if it is list.
    if (currentBlockType === 'unordered-list-item' || currentBlockType === 'ordered-list-item') {
      currentBlockType = 'unstyled';
    }
    const currentLabels = this.blocksTypes.filter((blk) => blk.style === currentBlockType);
    const currentLabel = currentLabels && currentLabels[0] && currentLabels[0].label;
    return (
      <div className={styles.block_wrapper}>
        <Dropdown
          className={styles.block_dropdown}
          onChange={this._onChange}
        >
          <span>{currentLabel}</span>
          {
            this.blocksTypes.map((block, index) =>
              <DropdownOption
                active={currentBlockType === block.style}
                value={block.style}
                key={index}
              >
                {block.label}
              </DropdownOption>)
          }
        </Dropdown>
      </div>
    );
  }
}
