/* @flow */

import React, { Component, PropTypes } from 'react';
import styles from './styles.css';
import classNames from 'classnames';

export default class Select extends Component {

  static propTypes = {
    children: PropTypes.array.isRequired,
    onChange: PropTypes.func,
    className: PropTypes.string,
    optionWrapperClassName: PropTypes.string,
  };

  state: Object = {
    expanded: false,
    highlighted: -1,
  };

  _onChange:Function = (value) => {
    const { onChange } = this.props;
    if (onChange) {
      onChange(value);
    }
    this._toggleExpansion();
  };

  _toggleExpansion:Function = () => {
    const expanded = !this.state.expanded;
    this.setState({
      expanded,
    });
  };

  _collapseExpansion:Function = () => {
    this.setState({
      expanded: false,
    });
  };

  _setHighlighted:Function = (highlighted) => {
    this.setState({
      highlighted,
    });
  };

  _onKeyDown: Function = (event) => {
    event.preventDefault();
    const { children } = this.props;
    const { expanded, highlighted } = this.state;
    if (event.key === 'ArrowDown' || event.key === 'ArrowRight') {
      if (!expanded) {
        this._toggleExpansion();
      } else {
        this._setHighlighted((highlighted === children[1].length - 1) ? 0 : highlighted + 1);
      }
    } else if (event.key === 'ArrowUp' || event.key === 'ArrowLeft') {
      this._setHighlighted(highlighted <= 0 ? children[1].length - 1 : highlighted - 1);
    } else if (event.key === 'Enter') {
      if (highlighted > -1) {
        this._onChange(this.props.children[1][highlighted].props.value);
      } else {
        this._toggleExpansion();
      }
    }
  };

  render() {
    const { children, className, optionWrapperClassName } = this.props;
    const { expanded, highlighted } = this.state;
    const options = children.slice(1, children.length);
    return (
      <div
        tabIndex="0"
        onKeyDown={this._onKeyDown}
        className={`${styles.dd_wrapper} ${className}`}
        onMouseLeave={this._collapseExpansion}
      >
        <a
          className={styles.dd_selectedText}
          onClick={this._toggleExpansion}
        >
          {children[0]}
          <div
            className={classNames({
              [`${styles.dd_caretToClose}`]: expanded,
              [`${styles.dd_caretToOpen}`]: !expanded,
            })}
          />
        </a>
        {expanded ?
          <ul
            className={`${styles.dd_optionWrapper} ${optionWrapperClassName}`}
          >
          {
            React.Children.map(options, (option, index) => {
              const temp = React.cloneElement(
                option, {
                  onSelect: this._onChange,
                  isHighlighted: highlighted === index,
                  setHighlighted: this._setHighlighted,
                  index,
                });
              return temp;
            })
          }
          </ul> : undefined}
      </div>
    );
  }
}
