/* @flow */

import React, { Component, PropTypes } from 'react';
import styles from './styles.css';
import classNames from 'classnames';

export default class DropDownOption extends Component {

  static propTypes = {
    onSelect: PropTypes.func,
    value: PropTypes.any,
    children: PropTypes.any.isRequired,
    active: PropTypes.bool,
    className: PropTypes.string,
    activeClassName: PropTypes.string,
    isHighlighted: PropTypes.bool,
    setHighlighted: PropTypes.func,
    index: PropTypes.number,
  };

  _onClick: Function = (): void => {
    const { onSelect, value } = this.props;
    if (onSelect) {
      onSelect(value);
    }
  };

  _setHighlighted: Function = () => {
    this.props.setHighlighted(this.props.index);
  };

  _resetHighlighted: Function = () => {
    this.props.setHighlighted(-1);
  };

  render(): Object {
    const {
      children,
      active,
      className,
      activeClassName,
      isHighlighted,
     } = this.props;
    return (
      <li
        className={classNames(
            styles.dd_option,
            className,
            { [`${styles.dd_option_active} ${activeClassName}`]: active,
              [`${styles.dd_option_highlighted}`]: isHighlighted })
        }
        onMouseEnter={this._setHighlighted}
        onMouseLeave={this._resetHighlighted}
        onClick={this._onClick}
      >
        {children}
      </li>
    );
  }
}
