/* @flow */

import React from 'react';
import { expect } from 'chai';
import { spy } from 'sinon';
import { shallow, mount } from 'enzyme';
import HistoryControl from '..';

describe('HistoryControl test suite', () => {
  it('should have a div when rendered', () => {
    expect(shallow(
      <HistoryControl
        undoDisabled={false}
        redoDisabled={false}
        undo={() => {}}
        redo={() => {}}
      />
    ).node.type).to.equal('div');
  });

  it('should have 2 child elements', () => {
    const controls = mount(
      <HistoryControl
        undoDisabled={false}
        redoDisabled={false}
        undo={() => {}}
        redo={() => {}}
      />
    );
    expect(controls.children().length).to.equal(2);
  });

  it('should execute undo if first child is clicked', () => {
    const undo = spy();
    const controls = mount(
      <HistoryControl
        undoDisabled={false}
        redoDisabled={false}
        undo={undo}
        redo={() => {}}
      />
    );
    controls.childAt(0).simulate('click');
    expect(undo.calledOnce).to.equal(true);
  });

  it('should not execute undo if undodisabled is true', () => {
    const undo = spy();
    const controls = mount(
      <HistoryControl
        undoDisabled
        redoDisabled={false}
        undo={undo}
        redo={() => {}}
      />
    );
    controls.childAt(0).simulate('click');
    expect(undo.called).to.equal(false);
  });

  it('should execute redo if second child is clicked', () => {
    const redo = spy();
    const controls = mount(
      <HistoryControl
        undoDisabled={false}
        redoDisabled={false}
        undo={() => {}}
        redo={redo}
      />
    );
    controls.childAt(1).simulate('click');
    expect(redo.calledOnce).to.equal(true);
  });

  it('should not execute redo if redodisabled is true', () => {
    const redo = spy();
    const controls = mount(
      <HistoryControl
        undoDisabled={false}
        redoDisabled
        undo={() => {}}
        redo={redo}
      />
    );
    controls.childAt(1).simulate('click');
    expect(redo.called).to.equal(false);
  });
});
