/* @flow */

import React from 'react';
import { expect, assert } from 'chai';
import { spy } from 'sinon';
import { shallow, mount } from 'enzyme';
import InlineControl from '..';

describe('InlineControl test suite', () => {
  it('should have a div when rendered', () => {
    expect(shallow(
      <InlineControl
        onToggle={() => {}}
        currentInlineStyles={{
          BOLD: false,
          ITALIC: false,
          UNDERLINE: false,
        }}
      />
    ).node.type).to.equal('div');
  });

  it('should have 3 child elements by default', () => {
    const control = mount(
      <InlineControl
        onToggle={() => {}}
        currentInlineStyles={{
          BOLD: false,
          ITALIC: false,
          UNDERLINE: false,
        }}
      />
    );
    expect(control.children().length).to.equal(3);
  });

  it('should have 1 child elements if inlineControlInDropdown is true', () => {
    const control = mount(
      <InlineControl
        onToggle={() => {}}
        currentInlineStyles={{
          BOLD: false,
          ITALIC: false,
          UNDERLINE: false,
        }}
        inlineControlInDropdown
      />
    );
    expect(control.children().length).to.equal(1);
    expect(control.childAt(0).children().length).to.equal(2);
  });

  it('should execute onToggle when child elements are clicked', () => {
    const onToggle = spy();
    const control = mount(
      <InlineControl
        onToggle={onToggle}
        currentInlineStyles={{
          BOLD: false,
          ITALIC: false,
          UNDERLINE: false,
        }}
      />
    );
    control.childAt(0).simulate('click');
    assert.isTrue(onToggle.calledOnce);
    assert.isTrue(onToggle.calledWith('BOLD'));
    control.childAt(1).simulate('click');
    assert.equal(onToggle.callCount, 2);
    assert.isTrue(onToggle.calledWith('ITALIC'));
    control.childAt(2).simulate('click');
    assert.equal(onToggle.callCount, 3);
    assert.isTrue(onToggle.calledWith('UNDERLINE'));
  });

  it('should make bold button active when currentInlineStyles is BOLD', () => {
    const onToggle = spy();
    const control = mount(
      <InlineControl
        onToggle={onToggle}
        currentInlineStyles={{
          BOLD: true,
          ITALIC: false,
          UNDERLINE: false,
        }}
      />
    );
    assert.isTrue(control.childAt(0).props().active);
    assert.isNotTrue(control.childAt(1).props().active);
  });
});
