/* @flow */

import React, { Component, PropTypes } from 'react';
import styles from './styles.css';
import Option from '../Option';
import { Dropdown, DropdownOption } from '../Dropdown';
import bold from '../../../../images/bold.svg';
import italic from '../../../../images/italic.svg';
import underline from '../../../../images/underline.svg';

export default class InlineControl extends Component {

  static propTypes = {
    onToggle: PropTypes.func.isRequired,
    currentInlineStyles: PropTypes.object.isRequired,
    inlineControlInDropdown: PropTypes.bool,
  };

  stylesMap: Array<Object> = [{
    key: 'b',
    value: 'BOLD',
    icon: bold,
  }, {
    key: 'i',
    value: 'ITALIC',
    icon: italic,
  }, {
    key: 'u',
    value: 'UNDERLINE',
    icon: underline,
  }];

  _renderInFlatList(onToggle: Function, currentInlineStyles: string): Object {
    return (
      <div className={styles.inline_wrapper}>
        {
          this.stylesMap.map((style) =>
            <Option
              key={style.key}
              value={style.value}
              onClick={onToggle}
              active={currentInlineStyles[style.value] === true}
            >
              <img
                src={style.icon}
                role="presentation"
              />
            </Option>
          )
        }
      </div>
    );
  }

  _renderInDropDown(onToggle: Function, currentInlineStyles: string): Object {
    return (
      <Dropdown
        className={styles.inline_dropdown}
        onChange={onToggle}
      >
        <img
          src={bold}
          role="presentation"
        />
        {
          this.stylesMap.map((style, index) =>
            <DropdownOption
              key={index}
              value={style.value}
              className={styles.inline_dropdownOption}
              active={currentInlineStyles[style.value] === true}
            >
              <span className={`${styles.inline_dropdownStyle}`}>
                <img
                  src={style.icon}
                  role="presentation"
                />
              </span>
            </DropdownOption>)
          }
      </Dropdown>
    );
  }

  render(): Object {
    const {
      onToggle,
      currentInlineStyles,
      inlineControlInDropdown,
    } = this.props;
    if (inlineControlInDropdown) {
      return this._renderInDropDown(onToggle, currentInlineStyles);
    }
    return this._renderInFlatList(onToggle, currentInlineStyles);
  }
}
