/* @flow */

import React from 'react';
import { expect, assert } from 'chai';
import { spy } from 'sinon';
import { shallow, mount } from 'enzyme';
import ListControl from '..';

describe('ListControl test suite', () => {
  it('should have a div when rendered', () => {
    expect(shallow(
      <ListControl
        onBlockTypeToggle={() => {}}
        onDepthChange={() => {}}
      />
    ).node.type).to.equal('div');
  });

  it('should have 4 child elements by default', () => {
    const control = mount(
      <ListControl
        onBlockTypeToggle={() => {}}
        onDepthChange={() => {}}
      />
    );
    expect(control.children().length).to.equal(4);
  });

  it('should have 1 child elements if listControlInDropdown is true', () => {
    const control = mount(
      <ListControl
        onBlockTypeToggle={() => {}}
        onDepthChange={() => {}}
        listControlInDropdown
      />
    );
    expect(control.children().length).to.equal(1);
    expect(control.childAt(0).children().length).to.equal(2);
  });

  it('should execute onBlockTypeToggle when any of first 2 child elements are clicked', () => {
    const onBlockTypeToggle = spy();
    const control = mount(
      <ListControl
        onBlockTypeToggle={onBlockTypeToggle}
        onDepthChange={() => {}}
      />
    );
    control.childAt(0).simulate('click');
    assert.isTrue(onBlockTypeToggle.calledOnce);
    assert.isTrue(onBlockTypeToggle.calledWith('unordered-list-item'));
    control.childAt(1).simulate('click');
    assert.equal(onBlockTypeToggle.callCount, 2);
    assert.isTrue(onBlockTypeToggle.calledWith('ordered-list-item'));
  });

  it('should execute onDepthChange when any of last 2 child elements are clicked', () => {
    const onDepthChange = spy();
    const control = mount(
      <ListControl
        onDepthChange={onDepthChange}
        onBlockTypeToggle={() => {}}
      />
    );
    control.childAt(2).simulate('click');
    assert.isTrue(onDepthChange.calledOnce);
    assert.isTrue(onDepthChange.calledWith(1));
    control.childAt(3).simulate('click');
    assert.equal(onDepthChange.callCount, 2);
    assert.isTrue(onDepthChange.calledWith(-1));
  });

  it('should make ordered-list button active when currentBlockType is ordered-list-item', () => {
    const control = mount(
      <ListControl
        onDepthChange={() => {}}
        onBlockTypeToggle={() => {}}
        currentBlockType="ordered-list-item"
      />
    );
    assert.isNotTrue(control.childAt(0).props().active);
    assert.isTrue(control.childAt(1).props().active);
  });
});
