/* @flow */

import React, { Component, PropTypes } from 'react';
import styles from './styles.css';
import Option from '../Option';
import {
  Dropdown,
  DropdownOption,
} from '../Dropdown';
import indent from '../../../../images/indent.svg';
import outdent from '../../../../images/outdent.svg';
import ordered from '../../../../images/list-ordered.svg';
import unordered from '../../../../images/list-unordered.svg';

export default class ListControl extends Component {

  static propTypes = {
    onDepthChange: PropTypes.func.isRequired,
    onBlockTypeToggle: PropTypes.func.isRequired,
    listControlInDropdown: PropTypes.bool,
    currentBlockType: PropTypes.string,
  };

  _onDropdownChange: Function = (value: string): void => {
    if (value === 'unordered-list-item' || value === 'ordered-list-item') {
      this.props.onBlockTypeToggle(value);
    } else if (value === 'indent') {
      this._indent();
    } else {
      this._outdent();
    }
  };

  _indent: Function = () => {
    this.props.onDepthChange(1);
  };

  _outdent: Function = () => {
    this.props.onDepthChange(-1);
  };

  _renderInFlatList(currentBlockType: string, onBlockTypeToggle: Function): Object {
    return (
      <div className={styles.list_wrapper}>
        <Option
          value="unordered-list-item"
          onClick={onBlockTypeToggle}
          active={currentBlockType === 'unordered-list-item'}
        >
          <img
            src={unordered}
            role="presentation"
          />
        </Option>
        <Option
          value="ordered-list-item"
          onClick={onBlockTypeToggle}
          active={currentBlockType === 'ordered-list-item'}
        >
          <img
            src={ordered}
            role="presentation"
          />
        </Option>
        <Option
          onClick={this._indent}
        >
          <img
            src={indent}
            role="presentation"
          />
        </Option>
        <Option
          onClick={this._outdent}
        >
          <img
            src={outdent}
            role="presentation"
          />
        </Option>
      </div>
    );
  }

  _renderInDropDown(currentBlockType: string): Object {
    return (
      <Dropdown
        className={styles.list_dropdown}
        onChange={this._onDropdownChange}
      >
        <img
          src={unordered}
          role="presentation"
        />
        <DropdownOption
          value="unordered-list-item"
          className={styles.list_dropdownOption}
          active={currentBlockType === 'unordered-list-item'}
        >
          <img
            src={unordered}
            role="presentation"
          />
        </DropdownOption>
        <DropdownOption
          value="ordered-list-item"
          className={styles.list_dropdownOption}
          active={currentBlockType === 'ordered-list-item'}
        >
          <img
            src={ordered}
            role="presentation"
          />
        </DropdownOption>
        <DropdownOption
          value="indent"
          className={styles.list_dropdownOption}
        >
          <img
            src={indent}
            role="presentation"
          />
        </DropdownOption>
        <DropdownOption
          value="outdent"
          className={styles.list_dropdownOption}
        >
          <img
            src={outdent}
            role="presentation"
          />
        </DropdownOption>
      </Dropdown>
    );
  }

  render(): Object {
    const {
      currentBlockType,
      onBlockTypeToggle,
      listControlInDropdown,
     } = this.props;
    if (listControlInDropdown) {
      return this._renderInDropDown(currentBlockType);
    }
    return this._renderInFlatList(currentBlockType, onBlockTypeToggle);
  }

}

// todo: test coverage
