/* @flow */

import React, { Component, PropTypes } from 'react';
import styles from './styles.css';
import Option from '../Option';
import {
  Dropdown,
  DropdownOption,
} from '../Dropdown';
import { Modifier, EditorState } from 'draft-js';
import left from '../../../../images/align-left.svg';
import center from '../../../../images/align-center.svg';
import right from '../../../../images/align-right.svg';
import justify from '../../../../images/align-justify.svg';

export default class TextAlignControl extends Component {

  static propTypes = {
    editorState: PropTypes.object.isRequired,
    onChange: PropTypes.func.isRequired,
    controlInDropdown: PropTypes.bool,
  };

  _addBlockAlignmentData:Function = (value: string) => {
    const { editorState, onChange } = this.props;
    const newContentState = Modifier.setBlockData(
     editorState.getCurrentContent(),
     editorState.getSelection(), {
       ['text-align']: value,
     });
    onChange(EditorState.push(editorState, newContentState, 'change-block-data'));
  }

  _renderInFlatList(): Object {
    return (
      <div className={styles.text_align_wrapper}>
        <Option
          value="left"
          onClick={this._addBlockAlignmentData}
        >
          <img
            src={left}
            role="presentation"
          />
        </Option>
        <Option
          value="center"
          onClick={this._addBlockAlignmentData}
        >
          <img
            src={center}
            role="presentation"
          />
        </Option>
        <Option
          value="right"
          onClick={this._addBlockAlignmentData}
        >
          <img
            src={right}
            role="presentation"
          />
        </Option>
        <Option
          value="justify"
          onClick={this._addBlockAlignmentData}
        >
          <img
            src={justify}
            role="presentation"
          />
        </Option>
      </div>
    );
  }

  _renderInDropDown(currentBlockType: string): Object {
    return (
      <Dropdown
        className={styles.text_align_dropdown}
        onChange={this._addBlockAlignmentData}
      >
        <img
          src={left}
          role="presentation"
        />
        <DropdownOption
          value="left"
          className={styles.text_align_dropdownOption}
          active={currentBlockType === 'unordered-list-item'}
        >
          <img
            src={left}
            role="presentation"
          />
        </DropdownOption>
        <DropdownOption
          value="center"
          className={styles.text_align_dropdownOption}
          active={currentBlockType === 'ordered-list-item'}
        >
          <img
            src={center}
            role="presentation"
          />
        </DropdownOption>
        <DropdownOption
          value="right"
          className={styles.text_align_dropdownOption}
        >
          <img
            src={right}
            role="presentation"
          />
        </DropdownOption>
        <DropdownOption
          value="justify"
          className={styles.text_align_dropdownOption}
        >
          <img
            src={justify}
            role="presentation"
          />
        </DropdownOption>
      </Dropdown>
    );
  }

  render(): Object {
    const { controlInDropdown } = this.props;
    if (controlInDropdown) {
      return this._renderInDropDown();
    }
    return this._renderInFlatList();
  }
}
