import { getBlockTag, getBlockContent } from './Block';

/**
* Function to check if a block is of type list.
*/
export function isList(block: Object): any {
  if (block) {
    const blockType = block.type;
    return (
      blockType === 'unordered-list-item' ||
      blockType === 'ordered-list-item'
    );
  }
  return undefined;
}

/**
* Function will recursively return html for a list block.
*/
export function getListHtml(listBlocks: Array<Object>, entityMap: Object): string {
  const listHtml = [];
  let nestedListBlock = [];
  let previousBlock;
  listBlocks.forEach((block) => {
    if (!previousBlock || previousBlock.type !== block.type) {
      if (previousBlock && previousBlock.type) {
        listHtml.push(`</${getBlockTag(previousBlock.type)}>`);
      }
      listHtml.push(`<${getBlockTag(block.type)}>`);
    }
    if (!previousBlock || previousBlock.depth === block.depth) {
      if (nestedListBlock && nestedListBlock.length > 0) {
        listHtml.push('<li>');
        listHtml.push(getListHtml(nestedListBlock));
        listHtml.push('</li>');
        nestedListBlock = [];
      }
      listHtml.push('<li>');
      listHtml.push(getBlockContent(block, entityMap));
      listHtml.push('</li>');
      previousBlock = block;
    } else {
      nestedListBlock.push(block);
    }
  });
  if (nestedListBlock && nestedListBlock.length > 0) {
    listHtml.push('<li>');
    listHtml.push(getListHtml(nestedListBlock));
    listHtml.push('</li>');
  }
  listHtml.push(`</${getBlockTag(previousBlock.type)}>`);
  return listHtml.join('');
}
