/* @flow */

import { assert } from 'chai';
import {
  colorIsBlockLevel,
  isSameAsPrevious,
  getInlineHtmlFragment,
} from '../Inline';

describe('isSameAsPrevious test suite', () => {
  const inlineStyles = {
    BOLD: [true, true, false],
    ITALIC: [false, false, true],
    UNDERLINE: [false, false, true],
    COLOR: ['rgb(0,0,0)', 'rgb(0,0,0)', 'rgb(100,100,100)'],
  };

  it('should return false for 0 index', () => {
    assert.isNotTrue(isSameAsPrevious(inlineStyles, 0));
  });

  it('should return true for index 1 as it is same as previous', () => {
    assert.isTrue(isSameAsPrevious(inlineStyles, 1));
  });

  it('should return false for index 2 as it is not same as previous', () => {
    assert.isNotTrue(isSameAsPrevious(inlineStyles, 2));
  });

  it('should return undefined for indexout of range', () => {
    assert.isUndefined(isSameAsPrevious(inlineStyles, 3));
  });
});

describe('colorIsBlockLevel test suite', () => {
  const colors1 = new Array(5);
  const colors2 = ['rgb(0,0,0)', 'rgb(0,0,0)', 'rgb(0,0,0)'];
  const colors3 = ['rgb(0,0,0)', 'rgb(1,1,1)', 'rgb(0,0,0)'];

  it('should return false if no color has been added', () => {
    assert.isNotTrue(colorIsBlockLevel(colors1));
  });
  it('should return true if all colors in array are same', () => {
    assert.isTrue(colorIsBlockLevel(colors2));
  });
  it('should return false if all colors in array are not same', () => {
    assert.isNotTrue(colorIsBlockLevel(colors3));
  });
});

describe('getInlineHtmlFragment test suite', () => {
  it('should return correct string for BOLD styles', () => {
    assert.equal(getInlineHtmlFragment('BOLD', 'testing'), '<strong>testing</strong>');
  });
  it('should return correct string for UNDERLINE styles', () => {
    assert.equal(getInlineHtmlFragment('UNDERLINE', 'testing'), '<ins>testing</ins>');
  });
  it('should return correct string for ITALIC styles', () => {
    assert.equal(getInlineHtmlFragment('ITALIC', 'testing'), '<em>testing</em>');
  });
  it('should return correct string for COLOR styles', () => {
    assert.equal(getInlineHtmlFragment(
      'COLOR', 'testing', 'rgb(0,0,0)'),
      '<span style="color: rgb(0,0,0)">testing</span>'
    );
  });
});
