/* @flow */

import {
  RichUtils,
  EditorState,
  convertFromHTML,
  ContentState,
} from 'draft-js';
import {
  colors,
  fontSizes,
  customInlineStylesMap,
  getInlineStylesOfSelection,
  toggleInlineStyle,
  customStyleMap,
} from '../Inline';
import { assert } from 'chai';
import { forEach, size } from '../../Common';

describe('getInlineStylesOfSelection, toggleInlineStyle test suite', () => {
  it('should correctly get color of selection', () => {
    const contentBlocks = convertFromHTML('<h1>aaaaaaaaaa</h1><ul><li>test</li></ul>');
    const contentState = ContentState.createFromBlockArray(contentBlocks);
    let editorState = EditorState.createWithContent(contentState);
    const updatedSelection = editorState.getSelection().merge({
      anchorOffset: 0,
      focusOffset: 10,
    });
    editorState = EditorState.acceptSelection(
      editorState,
      updatedSelection
    );
    editorState = toggleInlineStyle(editorState, 'color', 'rgb(97,189,109)');
    assert.equal(getInlineStylesOfSelection(editorState).COLOR, 'rgb(97,189,109)');
  });

  it('should correctly get color of selection', () => {
    const contentBlocks = convertFromHTML('<h1>aaaaaaaaaa</h1><ul><li>test</li></ul>');
    const contentState = ContentState.createFromBlockArray(contentBlocks);
    let editorState = EditorState.createWithContent(contentState);
    const updatedSelection = editorState.getSelection().merge({
      anchorOffset: 0,
      focusOffset: 10,
    });
    editorState = EditorState.acceptSelection(
      editorState,
      updatedSelection
    );
    editorState = RichUtils.toggleInlineStyle(
      editorState,
      'BOLD'
    );
    assert.equal(getInlineStylesOfSelection(editorState).BOLD, true);
  });
});

describe('ColorUtils test suite', () => {
  it('should initializa colors with an array of colors', () => {
    assert.isTrue(colors instanceof Array);
  });
  it('should initializa fontSizes with an array of numbers', () => {
    assert.isTrue(fontSizes instanceof Array);
  });
  it('should initializa colorStyleMap with a map of color styles', () => {
    assert.isTrue(customInlineStylesMap instanceof Object);
    forEach(customInlineStylesMap.color, (key, value) => {
      assert.isDefined(value.color);
    });
    forEach(customInlineStylesMap.fontSize, (key, value) => {
      assert.isDefined(value.fontSize);
    });
  });
  it('should initializa customStyleMap with a map of color styles and fontsizes', () => {
    assert.isTrue(customStyleMap instanceof Object);
    forEach(customStyleMap, (key, value) => {
      assert.isDefined(value.color || value.fontSize);
    });
    assert.equal(size(customStyleMap), size(colors) + size(fontSizes));
  });
});
